import{B as c}from"./BookOutlined.f3bced1b.js";import{d as f,o as s,c as d,w as o,b as l,u as n,dA as u,et as i,ar as p,aD as b,bG as y}from"./vue-router.e016c212.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="6caa6e79-0c2c-41f0-bff0-b8c7141fe5ea",t._sentryDebugIdIdentifier="sentry-dbid-6caa6e79-0c2c-41f0-bff0-b8c7141fe5ea")}catch{}})();const g=f({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var a;return s(),d(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[l(n(c))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(s(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.31878121.js.map
