import{g as _}from"./api.bad676dc.js";import{W as g}from"./Watermark.ea13460d.js";import{i as h}from"./metadata.0d102b4c.js";import{a as b}from"./asyncComputed.10de8a4b.js";import{W as k}from"./WidgetsFrame.1ad3be72.js";import{F as w}from"./PhArrowSquareOut.vue.641159d0.js";import{d as v,eM as x,f as C,u as e,o as s,c,w as t,ev as D,b as n,cN as d,ar as f,et as F,eC as I,cV as u,eD as V,ez as W,aD as z,R as N}from"./vue-router.e016c212.js";import"./index.a3706974.js";import{C as T}from"./Card.9ce1d00f.js";import"./router.c2cd5412.js";import"./runnerData.0217e333.js";import"./url.3a22c66f.js";import"./PhCheckCircle.vue.13815acd.js";import"./PhKanban.vue.ff012fc2.js";import"./PhWebhooksLogo.vue.efb3e200.js";import"./TabPane.6891f56b.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="941e5649-8ada-41d5-a99c-2907679291bf",o._sentryDebugIdIdentifier="sentry-dbid-941e5649-8ada-41d5-a99c-2907679291bf")}catch{}})();const B=v({__name:"Home",setup(o){const i=x(),{result:a}=b(_),m=C(()=>{var r;return((r=a.value)==null?void 0:r.sidebar.filter(p=>p.id!=="home"))||[]}),y=r=>{i.push({path:`/${r}`})};return(r,p)=>e(a)?(s(),c(k,{key:0,class:"home-container","main-color":e(a).mainColor,theme:e(a).theme,"font-family":e(a).fontFamily},{default:t(()=>[n(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:t(()=>[m.value.length===0?(s(),c(e(d),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:t(()=>[f(" There are no forms available for you. ")]),_:1})):(s(!0),F(z,{key:1},I(m.value,l=>(s(),c(e(T),{key:l.id,class:"form-card",onClick:H=>y(l.path)},{default:t(()=>[n(e(u),{gap:"large",align:"center",justify:"space-between"},{default:t(()=>[(s(),c(V(e(h)(l.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),n(e(d),{style:{"font-size":"18px","font-weight":"500"}},{default:t(()=>[f(W(l.name),1)]),_:2},1024),n(e(w),{size:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}),n(g,{class:"watermark","page-id":"home",locale:e(a).language},null,8,["locale"])]),_:1},8,["main-color","theme","font-family"])):D("",!0)}});const X=N(B,[["__scopeId","data-v-06807ab2"]]);export{X as default};
//# sourceMappingURL=Home.c02a3f40.js.map
