import{O as c}from"./router.c2cd5412.js";import{d,Z as l,o as i,et as u,b as a,w as n,u as o,ar as s,cR as f,cQ as b}from"./vue-router.e016c212.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ac6770b9-8c5f-424e-bc62-645e792241c7",e._sentryDebugIdIdentifier="sentry-dbid-ac6770b9-8c5f-424e-bc62-645e792241c7")}catch{}})();const p=d({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new c().loginCallback()}),(t,r)=>(i(),u("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.227fb439.js.map
