import{a as g}from"./asyncComputed.10de8a4b.js";import{d as y,eA as _,Z as b,u as e,o as l,c as w,et as x,b as a,w as o,cR as C,ar as p,cV as h,bG as I,a as k,ez as v}from"./vue-router.e016c212.js";import"./gateway.cb160cc2.js";import"./tables.201b204f.js";import{O as z}from"./organization.5524c59a.js";import{C as c}from"./router.de4b25c8.js";import{L as B}from"./LoadingContainer.bbd86aa8.js";import{A as D}from"./index.557b0769.js";import{C as N}from"./Card.9ce1d00f.js";import"./popupNotifcation.c9c9aa91.js";import"./record.c4c2199a.js";import"./string.8ec7016b.js";import"./TabPane.6891f56b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="94a0f80a-8f2a-4517-8733-8b86506e470b",t._sentryDebugIdIdentifier="sentry-dbid-94a0f80a-8f2a-4517-8733-8b86506e470b")}catch{}})();const A={key:1},M={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},J=y({__name:"Billing",setup(t){const s=_().params.organizationId,{loading:f,result:u}=g(()=>z.get(s));b(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const m=()=>c.showNewMessage("I want to upgrade my plan");return(V,j)=>e(f)?(l(),w(B,{key:0})):(l(),x("div",A,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(C),{level:3},{default:o(()=>[p("Current plan")]),_:1})]),_:1}),a(e(D),{style:{"margin-top":"0"}}),a(e(N),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[p("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",M,v((d=(i=(r=e(u))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{J as default};
//# sourceMappingURL=Billing.d9bed9a3.js.map
