import{O as c}from"./router.c2cd5412.js";import{d as r,Z as l,o as u,et as i,b as a,w as o,u as n,ar as d,cR as f,cQ as y}from"./vue-router.e016c212.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0254cc79-7c0c-4aa3-9dd4-c9cd5492d21a",e._sentryDebugIdIdentifier="sentry-dbid-0254cc79-7c0c-4aa3-9dd4-c9cd5492d21a")}catch{}})();const w=r({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new c().logoutCallback()}),(t,s)=>(u(),i("div",null,[a(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),a(n(y),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.9d672949.js.map
