import{g as m}from"./api.bad676dc.js";import{_ as u}from"./Login.vue_vue_type_script_setup_true_lang.0b71a838.js";import{u as d}from"./router.c2cd5412.js";import{a as f}from"./asyncComputed.10de8a4b.js";import{W as p}from"./WidgetsFrame.1ad3be72.js";import{d as _,eM as l,eA as y,u as r,o as g,c as b,w as h,ev as w,b as I,R as k}from"./vue-router.e016c212.js";import"./runnerData.0217e333.js";import"./url.3a22c66f.js";import"./CircularLoading.bc9bfe39.js";import"./index.73863b81.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4d633511-a644-482f-9d09-4f952957c50b",e._sentryDebugIdIdentifier="sentry-dbid-4d633511-a644-482f-9d09-4f952957c50b")}catch{}})();const v=_({__name:"Login",setup(e){const t=l(),s=y(),{result:o}=f(m),i=d(),c=async()=>{await i.signUp();const{redirect:a,...n}=s.query;if(a){await t.push({path:a,query:n,params:s.params});return}t.push({name:"playerHome",query:n})};return(a,n)=>r(o)?(g(),b(p,{key:0,"main-color":r(o).mainColor,theme:r(o).theme,"font-family":r(o).fontFamily,class:"runner"},{default:h(()=>[I(u,{onDone:c})]),_:1},8,["main-color","theme","font-family"])):w("",!0)}});const S=k(v,[["__scopeId","data-v-9e2c7105"]]);export{S as default};
//# sourceMappingURL=Login.92cb9de1.js.map
