import{C as d}from"./ContentLayout.6c69a32b.js";import{d as y,L as w,N as l,e as g,o as e,c as n,w as f,b as i,u as o,ev as s}from"./vue-router.e016c212.js";import{K as _,_ as v,W as K,E,a as R}from"./WorkflowView.747ac186.js";import{E as T}from"./api.a5dc8dfa.js";import{A as p,T as V}from"./TabPane.6891f56b.js";import"./fetch.62231b97.js";import"./linters.d2e2b8bc.js";import"./asyncComputed.10de8a4b.js";import"./scripts.d17cfd41.js";import"./record.c4c2199a.js";import"./metadata.0d102b4c.js";import"./PhCheckCircle.vue.13815acd.js";import"./PhKanban.vue.ff012fc2.js";import"./PhWebhooksLogo.vue.efb3e200.js";import"./ant-design.6def081f.js";import"./index.7eacc144.js";import"./index.1eba9f45.js";import"./index.370288f3.js";import"./index.dfd5326e.js";import"./CollapsePanel.ef59ae4c.js";import"./index.557b0769.js";import"./index.284be59d.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.4ba68a01.js";import"./model.a6abef34.js";import"./workspaces.bf6aae79.js";import"./runnerData.0217e333.js";import"./url.3a22c66f.js";import"./validations.d89a1a2a.js";import"./string.8ec7016b.js";import"./PhArrowSquareOut.vue.641159d0.js";import"./index.3e835cba.js";import"./Badge.0a4cba17.js";import"./index.73863b81.js";import"./Card.9ce1d00f.js";import"./uuid.18865231.js";import"./LoadingOutlined.e2f1014b.js";import"./DeleteOutlined.ac93eae5.js";import"./PhDownloadSimple.vue.bd4d7cdc.js";import"./utils.71dcf582.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="70a05f2c-acca-4af8-bbcd-738b563c7300",a._sentryDebugIdIdentifier="sentry-dbid-70a05f2c-acca-4af8-bbcd-738b563c7300")}catch{}})();const uo=y({__name:"WorkflowThreads",setup(a){const t=new E,m=new R,c=new w(l.array(l.string()),"kanban-selected-stages"),u=new T,r=g("kanban");return(W,b)=>(e(),n(d,{"full-width":""},{default:f(()=>[i(o(V),{activeKey:r.value,"onUpdate:activeKey":b[0]||(b[0]=k=>r.value=k)},{default:f(()=>[i(o(p),{key:"kanban",tab:"Kanban View"}),i(o(p),{key:"table",tab:"Table View"}),i(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),r.value==="kanban"?(e(),n(_,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(c),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),r.value==="table"?(e(),n(v,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),r.value==="workflow"?(e(),n(K,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{uo as default};
//# sourceMappingURL=WorkflowThreads.bba777bb.js.map
