import{a6 as i,dh as d}from"./vue-router.e016c212.js";import{g as c}from"./index.673228ff.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="72bb27a7-51d9-4195-b91b-edb2a5555be7",e._sentryDebugIdIdentifier="sentry-dbid-72bb27a7-51d9-4195-b91b-edb2a5555be7")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:b,TimePicker:m,QuarterPicker:o,RangePicker:a}=c(d),u=i(n,{WeekPicker:r,MonthPicker:t,YearPicker:b,RangePicker:a,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{u as D,t as M,o as Q,a as R,r as W};
//# sourceMappingURL=dayjs.64120316.js.map
