import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.e485e011.js";import{d as s,eA as i,o as a,c as m,u as c}from"./vue-router.e016c212.js";import"./gateway.cb160cc2.js";import"./popupNotifcation.c9c9aa91.js";import"./fetch.62231b97.js";import"./record.c4c2199a.js";import"./SaveButton.0de13a7e.js";import"./ExclamationCircleOutlined.58135ab5.js";import"./CrudView.36f5326e.js";import"./router.de4b25c8.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.31878121.js";import"./BookOutlined.f3bced1b.js";import"./url.3a22c66f.js";import"./index.1eba9f45.js";import"./index.7eacc144.js";import"./PhRocketLaunch.vue.4bac908f.js";import"./asyncComputed.10de8a4b.js";import"./PhPencil.vue.1ef361a8.js";import"./index.73863b81.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="e6858a8e-8198-425a-9e6c-533b1c9515b4",o._sentryDebugIdIdentifier="sentry-dbid-e6858a8e-8198-425a-9e6c-533b1c9515b4")}catch{}})();const A=s({__name:"EnvVars",setup(o){const r=i().params.projectId,t=new p(r);return(d,u)=>(a(),m(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.40fc33ab.js.map
