import"./vue-router.e016c212.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="ec3603bb-d695-4d3c-bb8c-ffde3d58bf55",e._sentryDebugIdIdentifier="sentry-dbid-ec3603bb-d695-4d3c-bb8c-ffde3d58bf55")}catch{}})();const a=e=>{try{return new URL(e),!0}catch{return!1}},b=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([s,c])=>{t.searchParams.delete(s),n.set(s,c)}),`${t.origin}${t.pathname}?${n.toString()}`};export{a as i,b as m};
//# sourceMappingURL=url.3a22c66f.js.map
