import{d as n,o as a,et as d,a as s,dA as r,ex as c,R as l}from"./vue-router.e016c212.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7a02b228-cddc-4ac5-a870-d2ab93e9883f",e._sentryDebugIdIdentifier="sentry-dbid-7a02b228-cddc-4ac5-a870-d2ab93e9883f")}catch{}})();const _={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(a(),d("div",_,[s("div",{class:c(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const f=l(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.6c69a32b.js.map
