import{B as f}from"./BaseLayout.f694d2de.js";import{L as y}from"./Logo.9329afce.js";import{d as l,D as m,K as g,R as p,aL as v,aM as b,o as _,et as h,a as s,eu as n,eA as w,eM as L,Z as S,c as k,w as r,b as i,u as x}from"./vue-router.e016c212.js";import{u as B}from"./editor.9e2ea526.js";import{b as I}from"./index.b63097bb.js";import"./router.c2cd5412.js";import"./linters.d2e2b8bc.js";import"./asyncComputed.10de8a4b.js";import"./index.0f9a0901.js";import"./index.7eacc144.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a4954689-45b4-4362-8f2b-834939020d2e",e._sentryDebugIdIdentifier="sentry-dbid-a4954689-45b4-4362-8f2b-834939020d2e")}catch{}})();const D=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...g(o)}}});const P={class:"v-spinner"};function R(e,o,a,d,c,u){return v((_(),h("div",P,[s("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),s("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),s("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[b,e.loading]])}const $=p(D,[["render",R],["__scopeId","data-v-06538001"]]),K={class:"content"},j=l({__name:"ProjectLogin",setup(e){const o=w(),a=L(),d=B();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function u(){const t=o.query["api-key"];if(typeof t=="string")return t}return S(async()=>{const t=u();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(c),a.push({name:"workspace"})}),(t,z)=>(_(),k(f,null,{navbar:r(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:r(()=>[i(y)]),_:1})]),content:r(()=>[s("div",K,[i($)])]),_:1}))}});const Z=p(j,[["__scopeId","data-v-6ca995fe"]]);export{Z as default};
//# sourceMappingURL=ProjectLogin.160277f7.js.map
