import{d as i,o as n,c as p,w as a,b as s,u as r}from"./vue-router.e016c212.js";import"./linters.d2e2b8bc.js";import{W as m}from"./workspaces.bf6aae79.js";import{C as d}from"./ContentLayout.6c69a32b.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.e485e011.js";import"./asyncComputed.10de8a4b.js";import"./runnerData.0217e333.js";import"./url.3a22c66f.js";import"./record.c4c2199a.js";import"./gateway.cb160cc2.js";import"./popupNotifcation.c9c9aa91.js";import"./fetch.62231b97.js";import"./SaveButton.0de13a7e.js";import"./ExclamationCircleOutlined.58135ab5.js";import"./CrudView.36f5326e.js";import"./router.de4b25c8.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.31878121.js";import"./BookOutlined.f3bced1b.js";import"./index.1eba9f45.js";import"./index.7eacc144.js";import"./PhRocketLaunch.vue.4bac908f.js";import"./PhPencil.vue.1ef361a8.js";import"./index.73863b81.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="430c2904-06e1-46a2-84ba-762e1ad67e73",o._sentryDebugIdIdentifier="sentry-dbid-430c2904-06e1-46a2-84ba-762e1ad67e73")}catch{}})();const q=i({__name:"EnvVarsEditor",setup(o){const e=new c;return(t,u)=>(n(),p(d,null,{default:a(()=>[s(f,{"env-var-repository":r(e),mode:"editor","file-opender":r(m)},null,8,["env-var-repository","file-opender"])]),_:1}))}});export{q as default};
//# sourceMappingURL=EnvVarsEditor.cd9cfe7c.js.map
