import{R as d,o,et as n,dA as s,a,ev as c}from"./vue-router.e016c212.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8bc02d28-5201-4c6e-bc7c-16cffcb9f67e",e._sentryDebugIdIdentifier="sentry-dbid-8bc02d28-5201-4c6e-bc7c-16cffcb9f67e")}catch{}})();const r={},f={class:"base-layout"},i={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),n("div",f,[s(e.$slots,"sidebar",{},void 0,!0),a("section",i,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):c("",!0)])])}const y=d(r,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.f694d2de.js.map
