import{L as h}from"./LoadingContainer.bbd86aa8.js";import{S as C}from"./SaveButton.0de13a7e.js";import{C as x,W as A}from"./model.a6abef34.js";import{E as b}from"./api.a5dc8dfa.js";import{d as E,e as W,f as N,u as t,o,c as i,et as _,ev as y,b as d,w as r,a as w,aD as B,eC as V,cQ as k,ar as m,ez as f,eD as S,cw as T,cV as G,R as L}from"./vue-router.e016c212.js";import{w as F}from"./metadata.0d102b4c.js";import{a as M}from"./asyncComputed.10de8a4b.js";import{A as z}from"./index.7eacc144.js";import{A as I}from"./index.557b0769.js";import"./ExclamationCircleOutlined.58135ab5.js";import"./workspaces.bf6aae79.js";import"./runnerData.0217e333.js";import"./url.3a22c66f.js";import"./record.c4c2199a.js";import"./validations.d89a1a2a.js";import"./string.8ec7016b.js";import"./PhArrowSquareOut.vue.641159d0.js";import"./index.3e835cba.js";import"./Badge.0a4cba17.js";import"./isNumeric.75337b1e.js";import"./index.73863b81.js";import"./Card.9ce1d00f.js";import"./TabPane.6891f56b.js";import"./uuid.18865231.js";import"./fetch.62231b97.js";import"./PhCheckCircle.vue.13815acd.js";import"./PhKanban.vue.ff012fc2.js";import"./PhWebhooksLogo.vue.efb3e200.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[n]="316a871f-753a-4d13-ade5-cd52d25c6af1",s._sentryDebugIdIdentifier="sentry-dbid-316a871f-753a-4d13-ade5-cd52d25c6af1")}catch{}})();const P={key:1,class:"workflow-editor"},Q={class:"workflow-toolbar"},R=["onDragstart"],j=E({__name:"WorkflowEditor",setup(s){const n=W(null),u=N(()=>{var a;return(a=n.value)==null?void 0:a.gui}),v=new b,{result:l,loading:g}=M(()=>A.create(v)),D=(a,c)=>{var e,p;(e=c.dataTransfer)==null||e.setData("type",a),(p=u.value)==null||p.dragstart(a,c)};return(a,c)=>t(g)?(o(),i(h,{key:0})):(o(),_("div",P,[t(l)?(o(),i(x,{key:0,ref_key:"canvasGui",ref:n,model:t(l)},null,8,["model"])):y("",!0),d(t(G),null,{default:r(()=>[w("div",Q,[(o(!0),_(B,null,V(t(F).stages,e=>(o(),i(t(T),{key:e.typeName,placement:"top"},{title:r(()=>[d(t(z),null,{default:r(()=>[d(t(k),null,{default:r(()=>[m(f(e.title),1)]),_:2},1024),d(t(k),{keyboard:""},{default:r(()=>[m(f(e.key),1)]),_:2},1024)]),_:2},1024)]),content:r(()=>[m(f(e.description),1)]),default:r(()=>[w("span",{draggable:"true",onDragstart:p=>D(e.typeName,p)},[(o(),i(S(e.icon),{width:"18",height:"18",class:"toolbar-item"}))],40,R)]),_:2},1024))),128)),d(t(I),{type:"vertical"}),t(l)?(o(),i(C,{key:0,model:t(l),disabled:void 0,type:"primary"},null,8,["model"])):y("",!0)])]),_:1})]))}});const kt=L(j,[["__scopeId","data-v-de9c06f6"]]);export{kt as default};
//# sourceMappingURL=WorkflowEditor.1156bd0a.js.map
