import{P as m}from"./PlayerNavbar.f45bcf3f.js";import{u as _,b as f}from"./router.c2cd5412.js";import{d as h,eM as g,eA as s,f as y,r as v,o as b,et as w,b as r,u as i,a as L,R as I}from"./vue-router.e016c212.js";import"./metadata.0d102b4c.js";import"./PhCheckCircle.vue.13815acd.js";import"./PhKanban.vue.ff012fc2.js";import"./PhWebhooksLogo.vue.efb3e200.js";import"./asyncComputed.10de8a4b.js";import"./PhSignOut.vue.acd9422d.js";import"./api.bad676dc.js";import"./runnerData.0217e333.js";import"./url.3a22c66f.js";import"./index.0f9a0901.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="4948a907-4169-4371-9114-06ee9cac54e6",t._sentryDebugIdIdentifier="sentry-dbid-4948a907-4169-4371-9114-06ee9cac54e6")}catch{}})();const k={class:"main-container"},N={class:"content"},R=h({__name:"Main",setup(t){const e=g(),o=_(),c=s().path,u=({path:n})=>{e.push({path:`/${n}`})},p=()=>{e.push({name:"playerLogin"})},d=y(()=>!!s().meta.hideLogin);return f(()=>e.push({name:"playerLogin"})),(n,x)=>{var a;const l=v("RouterView");return b(),w("div",k,[r(m,{"current-path":i(c),"user-email":(a=i(o).user)==null?void 0:a.claims.email,onNavigate:u,onLoginClick:p,"hide-login":d.value},null,8,["current-path","user-email","hide-login"]),L("section",N,[r(l)])])}}});const q=I(R,[["__scopeId","data-v-c786764c"]]);export{q as default};
//# sourceMappingURL=Main.ecf201b6.js.map
