import"./vue-router.e016c212.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="b17cf46c-8c21-4282-b15f-884079bd88a8",e._sentryDebugIdIdentifier="sentry-dbid-b17cf46c-8c21-4282-b15f-884079bd88a8")}catch{}})();const f=(...e)=>window.fetch(...e);export{f as l};
//# sourceMappingURL=fetch.62231b97.js.map
