import{u as n}from"./router.c2cd5412.js";import{r as o,w as a}from"./runnerData.0217e333.js";import"./vue-router.e016c212.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="0df6d110-f801-430a-9b29-e3331c1447cf",t._sentryDebugIdIdentifier="sentry-dbid-0df6d110-f801-430a-9b29-e3331c1447cf")}catch{}})();async function d(t){const e=n(),r=await fetch(`/_pages/${t}`,{headers:e.authHeaders});if(r.status===404)return null;if(!r.ok)throw new Error(await r.text());const{form:s}=await r.json();return s?o(s):null}async function i(){const t=n(),e=await fetch("/_workspace",{headers:t.authHeaders});if(e.status!=200)return a({});const r=await e.json();return a(r)}export{d as f,i as g};
//# sourceMappingURL=api.bad676dc.js.map
