import{d as o,o as s,et as a,b as d,u as r,bj as _,R as c}from"./vue-router.e016c212.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="6ec7208d-c056-49a9-b95f-d0f46051e9e3",e._sentryDebugIdIdentifier="sentry-dbid-6ec7208d-c056-49a9-b95f-d0f46051e9e3")}catch{}})();const i={class:"centered"},f=o({__name:"LoadingContainer",setup(e){return(n,t)=>(s(),a("div",i,[d(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.bbd86aa8.js.map
