import{u as k}from"./router.c2cd5412.js";import{d as _,L as w,N as b,e as g,o as r,et as v,b as s,w as h,u as e,c as p,ev as m,R as T}from"./vue-router.e016c212.js";import{K,_ as R,W as I,P,b as S}from"./WorkflowView.747ac186.js";import{P as V}from"./api.a5dc8dfa.js";import{A as c,T as x}from"./TabPane.6891f56b.js";import"./Card.9ce1d00f.js";import"./fetch.62231b97.js";import"./linters.d2e2b8bc.js";import"./asyncComputed.10de8a4b.js";import"./scripts.d17cfd41.js";import"./record.c4c2199a.js";import"./metadata.0d102b4c.js";import"./PhCheckCircle.vue.13815acd.js";import"./PhKanban.vue.ff012fc2.js";import"./PhWebhooksLogo.vue.efb3e200.js";import"./ant-design.6def081f.js";import"./index.7eacc144.js";import"./index.1eba9f45.js";import"./index.370288f3.js";import"./index.dfd5326e.js";import"./CollapsePanel.ef59ae4c.js";import"./index.557b0769.js";import"./index.284be59d.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.4ba68a01.js";import"./model.a6abef34.js";import"./workspaces.bf6aae79.js";import"./runnerData.0217e333.js";import"./url.3a22c66f.js";import"./validations.d89a1a2a.js";import"./string.8ec7016b.js";import"./PhArrowSquareOut.vue.641159d0.js";import"./index.3e835cba.js";import"./Badge.0a4cba17.js";import"./index.73863b81.js";import"./uuid.18865231.js";import"./LoadingOutlined.e2f1014b.js";import"./DeleteOutlined.ac93eae5.js";import"./PhDownloadSimple.vue.bd4d7cdc.js";import"./utils.71dcf582.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="ad8ca186-28a0-4ef0-bc53-f14680720c40",t._sentryDebugIdIdentifier="sentry-dbid-ad8ca186-28a0-4ef0-bc53-f14680720c40")}catch{}})();const W={class:"threads-view"},A=_({__name:"Threads",setup(t){const a=k().authHeaders,u=new V(a),i=new P(a),d=new S(a),y=new w(b.array(b.string()),"kanban-selected-stages"),o=g("kanban");return(B,l)=>(r(),v("div",W,[s(e(x),{activeKey:o.value,"onUpdate:activeKey":l[0]||(l[0]=f=>o.value=f)},{default:h(()=>[s(e(c),{key:"kanban",tab:"Kanban View"}),s(e(c),{key:"table",tab:"Table View"}),s(e(c),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(r(),p(K,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(y),"stage-run-repository":e(d)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(r(),p(R,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(r(),p(I,{key:2,"kanban-repository":e(i),"workflow-api":e(u)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=T(A,[["__scopeId","data-v-86c0b860"]]);export{ge as default};
//# sourceMappingURL=Threads.dabb6f8c.js.map
